==> okta-sdk-api-19.0.1-sources.jar: src/gen/java/main/com/okta/sdk/resource/model/AppCustomHrefObjectHints.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * Describes allowed HTTP verbs for the &#x60;href&#x60;
 */
@ApiModel(description = "Describes allowed HTTP verbs for the `href`")
@JsonPropertyOrder({ AppCustomHrefObjectHints.JSON_PROPERTY_ALLOW })
@JsonTypeName("AppCustomHrefObject_hints")
@javax.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2024-10-04T18:50:18.667445-05:00[America/Chicago]", comments = "Generator version: 7.8.0")
public class AppCustomHrefObjectHints implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_ALLOW = "allow";
    private List<String> allow = null;

    public AppCustomHrefObjectHints() {
    }

    public AppCustomHrefObjectHints allow(List<String> allow) {

        this.allow = allow;
        return this;
    }

    public AppCustomHrefObjectHints addallowItem(String allowItem) {
        if (this.allow == null) {
            this.allow = new ArrayList<>();
        }
        this.allow.add(allowItem);
        return this;
    }

    /**
     * Get allow
     *
     * @return allow
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_ALLOW)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public List<String> getAllow() {
        return allow;
    }

    @JsonProperty(JSON_PROPERTY_ALLOW)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setAllow(List<String> allow) {
        this.allow = allow;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        AppCustomHrefObjectHints appCustomHrefObjectHints = (AppCustomHrefObjectHints) o;
        return Objects.equals(this.allow, appCustomHrefObjectHints.allow);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(allow);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class AppCustomHrefObjectHints {\n");
        sb.append("    allow: ").append(toIndentedString(allow)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}

==> okta-sdk-api-20.0.1-sources.jar: src/gen/java/main/com/okta/sdk/resource/model/AppCustomHrefObjectHints.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * Describes allowed HTTP verbs for the &#x60;href&#x60;
 */
@ApiModel(description = "Describes allowed HTTP verbs for the `href`")
@JsonPropertyOrder({ AppCustomHrefObjectHints.JSON_PROPERTY_ALLOW })
@JsonTypeName("AppCustomHrefObject_hints")
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-01-23T09:50:29.349096-06:00[America/Chicago]", comments = "Generator version: 7.8.0")
public class AppCustomHrefObjectHints implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_ALLOW = "allow";
    private List<String> allow = null;

    public AppCustomHrefObjectHints() {
    }

    public AppCustomHrefObjectHints allow(List<String> allow) {

        this.allow = allow;
        return this;
    }

    public AppCustomHrefObjectHints addallowItem(String allowItem) {
        if (this.allow == null) {
            this.allow = new ArrayList<>();
        }
        this.allow.add(allowItem);
        return this;
    }

    /**
     * Get allow
     *
     * @return allow
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_ALLOW)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public List<String> getAllow() {
        return allow;
    }

    @JsonProperty(JSON_PROPERTY_ALLOW)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setAllow(List<String> allow) {
        this.allow = allow;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        AppCustomHrefObjectHints appCustomHrefObjectHints = (AppCustomHrefObjectHints) o;
        return Objects.equals(this.allow, appCustomHrefObjectHints.allow);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(allow);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class AppCustomHrefObjectHints {\n");
        sb.append("    allow: ").append(toIndentedString(allow)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}
